==> arkhitekton-0.1.0-sources.jar: universum/studios/android/arkhitekton/util/InstanceBuilder.kt <==
/*
 * =================================================================================================
 *                             Copyright (C) 2018 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.arkhitekton.util

import android.support.annotation.NonNull
import android.support.annotation.Nullable
import junit.framework.Assert.assertNotNull

/**
 * Performs a check verifying that the specified `argumentValue` is not `null`.
 *
 * If check fails, an exception with appropriate message is thrown.
 *
 * @param argumentClass  Class of the required argument of which value to check.
 * @param argumentValue Value of the required argument to verify that it is not `null`.
 * @throws AssertionError If the given argument value is actually `null`.
 */
fun checkArgumentValue(@NonNull argumentClass: Class<*>, @Nullable argumentValue: Any?) {
    checkArgumentValue(argumentClass.simpleName, argumentValue)
}

/**
 * Performs a check verifying that the specified `argumentValue` is not `null`.
 *
 * If check fails, an exception with appropriate message is thrown.
 *
 * @param argumentName  Name of the required argument of which value to check.
 * @param argumentValue Value of the required argument to verify that it is not `null`.
 * @throws AssertionError If the given argument value is actually `null`.
 */
fun checkArgumentValue(@NonNull argumentName: String, @Nullable argumentValue: Any?) {
    assertNotNull("No or null > $argumentName < specified!", argumentValue)
}

/**
 * Basic interface for builders used to create instances of a desired classes.
 *
 * Builder implementations are allowed to throw an [AssertionError] when [build] is called upon them
 * and there are some required arguments missing for a successful instance build.
 *
 * @param T Type of the class of which instance the builder can build.
 *
 * @author Martin Albedinsky
 * @since 1.0
 */
interface InstanceBuilder<out T> {

    /**
     * Builds a new instance of object specific for this builder.
     *
     * @return New instance ready to be used.
     * @throws AssertionError If some of the required arguments is not specified.
     */
    @NonNull fun build(): T
}

==> arkhitekton-0.2.0-sources.jar: universum/studios/android/arkhitekton/util/InstanceBuilder.kt <==
/*
 * =================================================================================================
 *                             Copyright (C) 2018 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.arkhitekton.util

import android.support.annotation.NonNull
import android.support.annotation.Nullable
import junit.framework.Assert.assertNotNull

/**
 * Performs a check verifying that the specified `argumentValue` is not `null`.
 *
 * If check fails, an exception with appropriate message is thrown.
 *
 * @param argumentClass  Class of the required argument of which value to check.
 * @param argumentValue Value of the required argument to verify that it is not `null`.
 * @throws AssertionError If the given argument value is actually `null`.
 */
@Deprecated("Use Preconditions.checkArgument(...) instead.", replaceWith = ReplaceWith("Preconditions.checkArgument"))
fun checkArgumentValue(@NonNull argumentClass: Class<*>, @Nullable argumentValue: Any?) {
    checkArgumentValue(argumentClass.simpleName, argumentValue)
}

/**
 * Performs a check verifying that the specified `argumentValue` is not `null`.
 *
 * If check fails, an exception with appropriate message is thrown.
 *
 * @param argumentName  Name of the required argument of which value to check.
 * @param argumentValue Value of the required argument to verify that it is not `null`.
 * @throws AssertionError If the given argument value is actually `null`.
 */
@Deprecated("Use Preconditions.checkArgument(...) instead.", replaceWith = ReplaceWith("Preconditions.checkArgument"))
fun checkArgumentValue(@NonNull argumentName: String, @Nullable argumentValue: Any?) {
    assertNotNull("No or null > $argumentName < specified!", argumentValue)
}

/**
 * Basic interface for builders used to create instances of a desired classes.
 *
 * Builder implementations are allowed to throw an [AssertionError] when [build] is called upon them
 * and there are some required arguments missing for a successful instance build.
 *
 * @param T Type of the class of which instance the builder can build.
 *
 * @author Martin Albedinsky
 * @since 1.0
 */
interface InstanceBuilder<out T> {

    /**
     * Builds a new instance of object specific for this builder.
     *
     * @return New instance ready to be used.
     * @throws AssertionError If some of the required arguments is not specified.
     */
    @NonNull fun build(): T
}
